@@ -3,7 +3,7 @@
 /*               This file is part of the program and library                */
 /*    PaPILO --- Parallel Presolve for Integer and Linear Optimization       */
 /*                                                                           */
-/* Copyright (C) 2020-2022 Konrad-Zuse-Zentrum                               */
+/* Copyright (C) 2020-2023 Konrad-Zuse-Zentrum                               */
 /*                     fuer Informationstechnik Berlin                       */
 /*                                                                           */
 /* This program is free software: you can redistribute it and/or modify      */
@@ -77,7 +77,7 @@ class Postsolve
    PostsolveStatus
    undo( const Solution<REAL>& reducedSolution,
          Solution<REAL>& originalSolution,
-         PostsolveStorage<REAL> postsolveStorage, bool is_optimal = true ) const;
+         const PostsolveStorage<REAL>& postsolveStorage, bool is_optimal = true ) const;
 
  private:
    REAL
@@ -177,7 +177,7 @@ template <typename REAL>
 PostsolveStatus
 Postsolve<REAL>::undo( const Solution<REAL>& reducedSolution,
                        Solution<REAL>& originalSolution,
-                       PostsolveStorage<REAL> postsolveStorage, bool is_optimal ) const
+                       const PostsolveStorage<REAL>& postsolveStorage, bool is_optimal ) const
 {
 
    PrimalDualSolValidation<REAL> validation{message, num};
@@ -382,7 +382,7 @@ Postsolve<REAL>::undo( const Solution<REAL>& reducedSolution,
          if( originalSolution.basisAvailabe )
             originalSolution.rowBasisStatus[indices[first]] =
                 VarBasisStatus::BASIC;
-         if( types[i - 1] == ReductionType::kSubstitutedColWithDual )
+         if( i >= 1 && types[i - 1] == ReductionType::kSubstitutedColWithDual )
             continue;
          break;
          // the remaining Types are used as additional information for other
