@@ -3,7 +3,7 @@
 /*               This file is part of the program and library                */
 /*    PaPILO --- Parallel Presolve for Integer and Linear Optimization       */
 /*                                                                           */
-/* Copyright (C) 2020-2022 Konrad-Zuse-Zentrum                               */
+/* Copyright (C) 2020-2023 Konrad-Zuse-Zentrum                               */
 /*                     fuer Informationstechnik Berlin                       */
 /*                                                                           */
 /* This program is free software: you can redistribute it and/or modify      */
@@ -739,8 +739,11 @@ MpsParser<REAL>::parseBounds( boost::iostreams::filtering_istream& file )
       }
       else
       {
-         std::cerr << "unknown bound type " << word_ref << std::endl;
-         exit( 1 );
+         if( word_ref == "INDICATORS" )
+            std::cerr << "PaPILO does not support INDICATORS in the MPS file!!"<< std::endl;
+         else
+            std::cerr << "unknown bound type " << word_ref << std::endl;
+         return parsekey::kFail;
       }
 
       // parse over next word
